@@ -5,5 +5,5 @@ from trdb2py.utils import str2asset, nextWeekDay, asset2str
 from trdb2py.timeutils import str2timestamp
 from trdb2py.pdutils import buildPNLReport
 from trdb2py.statistics import calcPNLWinRateInYear, buildPNLWinRateInYears, buildPNLWinRateInMonths, buildPNLListWinRateInYears2, buildPNLListWinRateInMonths2
-from trdb2py.plotly import showAssetCandles, showHeatmap, showHeatmapWinRateInYears, showWinRateInYears, showHeatmapWinRateInMonths, showWinRateInMonths
+from trdb2py.plotly import showAssetCandles, showHeatmap, showHeatmapWinRateInYears, showWinRateInYears, showHeatmapWinRateInMonths, showWinRateInMonths, showPNL, showPNLs
 import trdb2py.trading2_pb2
