@@ -38,7 +38,7 @@ def getAssetCandles(cfg: dict, asset: str, tsStart: int, tsEnd: int, dtFormat: s
     return pd.DataFrame(fv)
 
 
-def genSimTradingParams(cfg, lstParams: list, ignoreCache: bool = False):
+def genSimTradingParams(cfg, lstParams: list, ignoreTotalReturn: float = 0, ignoreCache: bool = False):
     for i in range(len(lstParams)):
         yield trdb2py.tradingdb2_pb2.RequestSimTrading(
             basicRequest=trdb2py.trading2_pb2.BasicRequestData(
@@ -47,16 +47,17 @@ def genSimTradingParams(cfg, lstParams: list, ignoreCache: bool = False):
             params=lstParams[i],
             ignoreCache=ignoreCache,
             index=i,
+            ignoreTotalReturn=ignoreTotalReturn,
         )
 
 
-def simTradings(cfg, lstParams: list, ignoreCache: bool = False) -> list:
+def simTradings(cfg, lstParams: list, ignoreTotalReturn: float = 0, ignoreCache: bool = False) -> list:
     channel = grpc.insecure_channel(cfg['servaddr'])
     stub = trdb2py.tradingdb2_pb2_grpc.TradingDB2Stub(channel)
 
     lstRes = []
     responses = stub.simTrading2(
-        genSimTradingParams(cfg, lstParams, ignoreCache))
+        genSimTradingParams(cfg, lstParams, ignoreTotalReturn=ignoreTotalReturn, ignoreCache=ignoreCache))
     for response in responses:
         if len(response.pnl) > 0:
             pnl = response.pnl[0]
